@@ -42,6 +42,7 @@
 #include <pwd.h>
 #include <stdlib.h>
 #include <string.h>
+#include <sys/param.h>
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <unistd.h>
@@ -79,7 +80,7 @@
 gchar*
 gnome_vfs_format_file_size_for_display (GnomeVFSFileSize size)
 {
-	if (size < (GnomeVFSFileSize) KILOBYTE_FACTOR) {		
+	if (size < (GnomeVFSFileSize) KILOBYTE_FACTOR) {
 		return g_strdup_printf (ngettext("%u byte", "%u bytes",(guint) size), (guint) size);
 	} else {
 		gdouble displayed_size;
@@ -758,7 +759,7 @@ gnome_vfs_get_uri_from_local_path (const char *local_full_path)
  * @size:
  * 
  * Stores in @size the amount of free space on a volume.
- * This only works for local file systems with the file: scheme.
+ * This only works for URIs with the file: scheme.
  *
  * Returns: GNOME_VFS_OK on success, otherwise an error code
  */
@@ -799,12 +800,35 @@ gnome_vfs_get_volume_free_space (const GnomeVFSURI *vfs_uri,
 	statfs_result = statfs (unescaped_path, &statfs_buffer);   
 #endif  
 
-	g_free (unescaped_path);
-
 	if (statfs_result != 0) {
+		g_free (unescaped_path);
 		return gnome_vfs_result_from_errno ();
 	}
-	
+
+	/* ncpfs does not know the amount of available and free space */
+	if (statfs_buffer.f_bavail == 0 && statfs_buffer.f_bfree == 0) {
+#if defined(__linux__)
+		/* statvfs does not contain an f_type field, we try again
+		 * with statfs.
+		 */
+		struct statfs statfs_buffer2;
+		statfs_result = statfs (unescaped_path, &statfs_buffer2);
+		g_free (unescaped_path);
+
+		if (statfs_result != 0) {
+			return gnome_vfs_result_from_errno ();
+		}
+		
+		/* linux/ncp_fs.h: NCP_SUPER_MAGIC == 0x564c */
+		if (statfs_buffer2.f_type == 0x564c)
+#elif defined(__sun)
+		if (strcmp(statfs_buffer.f_basetype, "ncpfs") == 0)
+#endif
+		{
+			return GNOME_VFS_ERROR_NOT_SUPPORTED;
+		}
+	}
+
 	block_size = statfs_buffer.f_bsize; 
 	free_blocks = statfs_buffer.f_bavail;
 
@@ -1221,6 +1245,33 @@ gnome_vfs_escape_high_chars (const guchar *string)
 	return result;
 }
 
+/* http uris look like <something>.<2-4 letters>, possibly followed by a slash and some text. */
+static gboolean
+looks_like_http_uri (const char *str)
+{
+	int len;
+	int i;
+	char c;
+	const char *first_slash;
+
+	first_slash = strchr(str, '/');
+	if (first_slash == NULL) {
+		len = strlen (str);
+	} else {
+		len = first_slash - str;
+	}
+	for (i = 0; i < 5 && i < len; i++) {
+		c = str[len - 1 - i];
+		if (i >= 2 && c == '.') {
+			return TRUE;
+		}
+		if (!g_ascii_isalpha (c)) {
+			return FALSE;
+		}
+	}
+	return FALSE;
+}
+
 /* The strip_trailing_whitespace option is intended to make copy/paste of
  * URIs less error-prone when it is known that trailing whitespace isn't
  * part of the uri.
@@ -1285,10 +1336,14 @@ gnome_vfs_make_uri_from_input_internal (const char *text,
 	default:
 		if (has_valid_scheme (stripped)) {
 			uri = gnome_vfs_escape_high_chars (stripped);
-		} else {
+		} else if (looks_like_http_uri (stripped)) {
 			escaped = gnome_vfs_escape_high_chars (stripped);
 			uri = g_strconcat ("http://", escaped, NULL);
 			g_free (escaped);
+		} else {
+			escaped = gnome_vfs_escape_high_chars (stripped);
+			uri = g_strconcat ("file://", escaped, NULL);
+			g_free (escaped);
 		}
 	}
 
